package com.jdbernard.nlsongs.servlet

import javax.servlet.ServletContext
import javax.servlet.ServletContextEvent
import javax.servlet.ServletContextListener

import com.jdbernard.wdiwtlt.db.DbApi

import com.zaxxer.hikari.HikariConfig
import com.zaxxer.hikari.HikariDataSource

public final class WdiwtltContextListener implements ServletContextListener {

    public void contextInitialized(ServletContextEvent event) {
        def context = event.servletContext

        // Load the context configuration.
        Properties props = new Properties()
        WdiwtltContextListener.getResourceAsStream(
            context.getInitParameter('context.config.file')).withStream { is ->
                props.load(is) }

        // Create the pooled data source
        HikariConfig hcfg = new HikariConfig(
            context.getInitParameter('datasource.config.file'))

        HikariDataSource hds = new HikariDataSource(hcfg)

        // Create the NLSonsDB instance.
        DbApi dbapi = new DbApi(hds)

        context.setAttribute('dbapi', dbapi)
        WdiwtltContext.dbapi = dbapi }

    public void contextDestroyed(ServletContextEvent event) {
        def context = event.servletContext

        // Shutdown the DB API instance (it will shut down the data source).
        DbApi dbapi = context.getAttribute('dbapi')
        if (dbapi) dbapi.shutdown()

        context.removeAttribute('dbapi') }
}
